@@ -1,3 +1,5 @@
 from . import vacancy_predictors_classified
 from . import vacancy_predictors
-from . import mach_finger
\ No newline at end of file
+from . import mach_finger
+from . import coeff_vacancy
+from . import vancy_network_keras
\ No newline at end of file
