@@ -5,7 +5,7 @@ from .vancy_network_keras import ModelConfig, VacancyClassifierKeras
 
 # Ajustá estas rutas
 ARTIFACTS_DIR = "artifacts_keras"  # donde guardaste best_model.keras, scaler, feature_order.json
-INPUT_CSV = "/mnt/data/finger_data_clasificado.csv"  # tu CSV de entrada
+INPUT_CSV = "outputs/csv/finger_data_full_features.csv"  # tu CSV de entrada
 OUTPUT_CSV = "outputs/csv/finger_data_predicho.csv"  # salida con predicciones
 
 def main():
