@@ -153,7 +153,11 @@ def VacancyAnalysis():
 
             #print(df_resultado[['archivo', 'grupo_predicho']])
 
+            df_key = pd.read_csv("outputs/csv/finger_key_files.csv")
+            df_cls = pd.read_csv("outputs/csv/defect_data.csv")
 
+            df_full = df_cls.merge(df_key, left_on="archivo", right_on="file_name", how="left")
+            df_full.to_csv("outputs/csv/finger_data_full_features.csv", index=False)
             #ETAPA DE PREDICCIONES
 
             trainer = VacancyModelTrainer(json_path="outputs/json/training_graph.json")
@@ -225,22 +229,10 @@ def VacancyAnalysis():
         pred, probs = clf.predict_one(sample)
         print(f"\nPredicción de vacancias (1..C): {pred}")
         print("Probabilidades:", probs)
-# ... (ya corriste exporter.export(), clf.classify_csv(...), etc.)
+        clf = VacancyClassifierKeras(ModelConfig(artifacts_dir="outputs/keras_artifacts"))
+        clf.load_artifacts(best=True)  # carga modelo + scaler + orden de features
+        clf.predict_csv("arcx.csv", "outputs/csv/arcx_predicho_keras.csv", return_probs=True)
 
-        try:
-            keras_out_csv = "outputs/csv/finger_data_predicho_keras.csv"
-            run_keras_classifier(
-                train_json_path="outputs/json/training_graph.json",
-                input_csv="outputs/csv/finger_data_clasificado.csv",
-                output_csv=keras_out_csv,
-                artifacts_dir="outputs/keras_artifacts",
-                retrain=False,  # poné True si querés reentrenar siempre
-                verbose=0
-            )
-        except Exception as e:
-            print(f"[KERAS] Aviso: no se pudo entrenar/predicir: {e}")
-
-                    
 
 if __name__ == "__main__":
     VacancyAnalysis()
